@@ -102,12 +102,12 @@ class Configuration(UserDict, IsConfiguration):
         name = key if self.name is None else f"{self.name}.{key}"
 
         # Treat dicts as nested configurations
-        if isinstance(value, dict):
+        if isinstance(value, (dict, UserDict)):
             self.data.setdefault(key, self.__class__(name=name, _vars=self.vars))
             self.data[key].update_from_dict(value, source=source)
 
         # Treat lists with nested elements as configuration lists
-        elif isinstance(value, list) and _is_nested(value):
+        elif isinstance(value, (list, UserList)) and _is_nested(value):
             self.data.setdefault(key, ConfigurationList(name=name, _vars=self.vars))
             self.data[key].update_from_list(value, source=source)
 
@@ -210,8 +210,7 @@ class Configuration(UserDict, IsConfiguration):
 
         Only actual sections are included, not top level entries.
         """
-        # return list(self._section_items())
-        return [s for s in self._section_items()]
+        return list(self._section_items())
 
     @property
     def sections(self) -> List["Configuration"]:
@@ -234,13 +233,14 @@ class Configuration(UserDict, IsConfiguration):
 
         Only actual sections are included, not top level entries.
         """
-        for section in self.data.values():
+        for section_name, section in self.data.items():
             if isinstance(section, IsConfiguration):
-                yield from section._flatten_section()
+                for flattened_section in section._flatten_section():
+                    yield section_name, flattened_section
 
-    def _flatten_section(self) -> List[Tuple[str, "Configuration"]]:
-        """Return configuration as a (name, Configuration) tuple"""
-        return [(self.name, self)]
+    def _flatten_section(self) -> List["Configuration"]:
+        """Return configuration as a list of one configuration"""
+        return [self]
 
     @property
     def entries(self) -> List[Tuple[str, Any]]:
@@ -271,7 +271,7 @@ class Configuration(UserDict, IsConfiguration):
     @property
     def leafs(self) -> List[Tuple["Configuration", str, Any]]:
         """List of all keys and values, recursively including subsections"""
-        return [lf for lf in self._leafs()]
+        return list(self._leafs())
 
     @property
     def leaf_keys(self) -> List[Tuple["Configuration", str]]:
@@ -585,14 +585,14 @@ class ConfigurationList(UserList, IsConfiguration):
         for entry in entries:
             self.update_entry(entry, source=source)
 
-    def _flatten_section(self) -> List[Tuple[str, "Configuration"]]:
-        """Return configuration as lists of (name, Configuration) tuple"""
-        return [(s.name, s) for s in self.data]
+    def _flatten_section(self) -> List["Configuration"]:
+        """Return configuration as a list of Configurations"""
+        return self.data
 
     @property
     def leafs(self) -> List[Tuple["Configuration", str, Any]]:
         """List of all keys and values, recursively including subsections"""
-        return [lf for lf in self._leafs()]
+        return list(self._leafs())
 
     @property
     def leaf_keys(self) -> List[Tuple["Configuration", str]]:
